# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/v1/room.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from bilibili.rpc import status_pb2 as bilibili_dot_rpc_dot_status__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n bilibili/broadcast/v1/room.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x19\x62ilibili/rpc/status.proto\x1a\x19google/protobuf/any.proto\"6\n\x0eRoomErrorEvent\x12$\n\x06status\x18\x01 \x01(\x0b\x32\x14.bilibili.rpc.Status\"\x0f\n\rRoomJoinEvent\"\x10\n\x0eRoomLeaveEvent\"K\n\x10RoomMessageEvent\x12\x13\n\x0btarget_path\x18\x01 \x01(\t\x12\"\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"5\n\x0fRoomOnlineEvent\x12\x0e\n\x06online\x18\x01 \x01(\x05\x12\x12\n\nall_online\x18\x02 \x01(\x05\"\xfe\x01\n\x07RoomReq\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x04join\x18\x02 \x01(\x0b\x32$.bilibili.broadcast.v1.RoomJoinEventH\x00\x12\x36\n\x05leave\x18\x03 \x01(\x0b\x32%.bilibili.broadcast.v1.RoomLeaveEventH\x00\x12\x38\n\x06online\x18\x04 \x01(\x0b\x32&.bilibili.broadcast.v1.RoomOnlineEventH\x00\x12\x36\n\x03msg\x18\x05 \x01(\x0b\x32\'.bilibili.broadcast.v1.RoomMessageEventH\x00\x42\x07\n\x05\x65vent\"\xb5\x02\n\x08RoomResp\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x04join\x18\x02 \x01(\x0b\x32$.bilibili.broadcast.v1.RoomJoinEventH\x00\x12\x36\n\x05leave\x18\x03 \x01(\x0b\x32%.bilibili.broadcast.v1.RoomLeaveEventH\x00\x12\x38\n\x06online\x18\x04 \x01(\x0b\x32&.bilibili.broadcast.v1.RoomOnlineEventH\x00\x12\x36\n\x03msg\x18\x05 \x01(\x0b\x32\'.bilibili.broadcast.v1.RoomMessageEventH\x00\x12\x34\n\x03\x65rr\x18\x06 \x01(\x0b\x32%.bilibili.broadcast.v1.RoomErrorEventH\x00\x42\x07\n\x05\x65vent2]\n\rBroadcastRoom\x12L\n\x05\x45nter\x12\x1e.bilibili.broadcast.v1.RoomReq\x1a\x1f.bilibili.broadcast.v1.RoomResp(\x01\x30\x01\x62\x06proto3')



_ROOMERROREVENT = DESCRIPTOR.message_types_by_name['RoomErrorEvent']
_ROOMJOINEVENT = DESCRIPTOR.message_types_by_name['RoomJoinEvent']
_ROOMLEAVEEVENT = DESCRIPTOR.message_types_by_name['RoomLeaveEvent']
_ROOMMESSAGEEVENT = DESCRIPTOR.message_types_by_name['RoomMessageEvent']
_ROOMONLINEEVENT = DESCRIPTOR.message_types_by_name['RoomOnlineEvent']
_ROOMREQ = DESCRIPTOR.message_types_by_name['RoomReq']
_ROOMRESP = DESCRIPTOR.message_types_by_name['RoomResp']
RoomErrorEvent = _reflection.GeneratedProtocolMessageType('RoomErrorEvent', (_message.Message,), {
  'DESCRIPTOR' : _ROOMERROREVENT,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomErrorEvent)
  })
_sym_db.RegisterMessage(RoomErrorEvent)

RoomJoinEvent = _reflection.GeneratedProtocolMessageType('RoomJoinEvent', (_message.Message,), {
  'DESCRIPTOR' : _ROOMJOINEVENT,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomJoinEvent)
  })
_sym_db.RegisterMessage(RoomJoinEvent)

RoomLeaveEvent = _reflection.GeneratedProtocolMessageType('RoomLeaveEvent', (_message.Message,), {
  'DESCRIPTOR' : _ROOMLEAVEEVENT,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomLeaveEvent)
  })
_sym_db.RegisterMessage(RoomLeaveEvent)

RoomMessageEvent = _reflection.GeneratedProtocolMessageType('RoomMessageEvent', (_message.Message,), {
  'DESCRIPTOR' : _ROOMMESSAGEEVENT,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomMessageEvent)
  })
_sym_db.RegisterMessage(RoomMessageEvent)

RoomOnlineEvent = _reflection.GeneratedProtocolMessageType('RoomOnlineEvent', (_message.Message,), {
  'DESCRIPTOR' : _ROOMONLINEEVENT,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomOnlineEvent)
  })
_sym_db.RegisterMessage(RoomOnlineEvent)

RoomReq = _reflection.GeneratedProtocolMessageType('RoomReq', (_message.Message,), {
  'DESCRIPTOR' : _ROOMREQ,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomReq)
  })
_sym_db.RegisterMessage(RoomReq)

RoomResp = _reflection.GeneratedProtocolMessageType('RoomResp', (_message.Message,), {
  'DESCRIPTOR' : _ROOMRESP,
  '__module__' : 'bilibili.broadcast.v1.room_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.RoomResp)
  })
_sym_db.RegisterMessage(RoomResp)

_BROADCASTROOM = DESCRIPTOR.services_by_name['BroadcastRoom']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROOMERROREVENT._serialized_start=113
  _ROOMERROREVENT._serialized_end=167
  _ROOMJOINEVENT._serialized_start=169
  _ROOMJOINEVENT._serialized_end=184
  _ROOMLEAVEEVENT._serialized_start=186
  _ROOMLEAVEEVENT._serialized_end=202
  _ROOMMESSAGEEVENT._serialized_start=204
  _ROOMMESSAGEEVENT._serialized_end=279
  _ROOMONLINEEVENT._serialized_start=281
  _ROOMONLINEEVENT._serialized_end=334
  _ROOMREQ._serialized_start=337
  _ROOMREQ._serialized_end=591
  _ROOMRESP._serialized_start=594
  _ROOMRESP._serialized_end=903
  _BROADCASTROOM._serialized_start=905
  _BROADCASTROOM._serialized_end=998
# @@protoc_insertion_point(module_scope)
