# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/broadcast/v1/test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n bilibili/broadcast/v1/test.proto\x12\x15\x62ilibili.broadcast.v1\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\"!\n\tAddParams\x12\t\n\x01\x61\x18\x01 \x01(\x05\x12\t\n\x01\x62\x18\x02 \x01(\x05\"\x16\n\tAddResult\x12\t\n\x01r\x18\x01 \x01(\x05\"c\n\x08TestResp\x12\x0e\n\x06taskid\x18\x01 \x01(\x03\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07message\x18\x03 \x01(\t\x12#\n\x05\x65xtra\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any2S\n\x04Test\x12K\n\x0eWatchTestEvent\x12\x16.google.protobuf.Empty\x1a\x1f.bilibili.broadcast.v1.TestResp0\x01\x32I\n\x05Test2\x12@\n\x04Test\x12 .bilibili.broadcast.v1.AddParams\x1a\x16.google.protobuf.Emptyb\x06proto3')



_ADDPARAMS = DESCRIPTOR.message_types_by_name['AddParams']
_ADDRESULT = DESCRIPTOR.message_types_by_name['AddResult']
_TESTRESP = DESCRIPTOR.message_types_by_name['TestResp']
AddParams = _reflection.GeneratedProtocolMessageType('AddParams', (_message.Message,), {
  'DESCRIPTOR' : _ADDPARAMS,
  '__module__' : 'bilibili.broadcast.v1.test_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.AddParams)
  })
_sym_db.RegisterMessage(AddParams)

AddResult = _reflection.GeneratedProtocolMessageType('AddResult', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESULT,
  '__module__' : 'bilibili.broadcast.v1.test_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.AddResult)
  })
_sym_db.RegisterMessage(AddResult)

TestResp = _reflection.GeneratedProtocolMessageType('TestResp', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESP,
  '__module__' : 'bilibili.broadcast.v1.test_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.broadcast.v1.TestResp)
  })
_sym_db.RegisterMessage(TestResp)

_TEST = DESCRIPTOR.services_by_name['Test']
_TEST2 = DESCRIPTOR.services_by_name['Test2']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ADDPARAMS._serialized_start=115
  _ADDPARAMS._serialized_end=148
  _ADDRESULT._serialized_start=150
  _ADDRESULT._serialized_end=172
  _TESTRESP._serialized_start=174
  _TESTRESP._serialized_end=273
  _TEST._serialized_start=275
  _TEST._serialized_end=358
  _TEST2._serialized_start=360
  _TEST2._serialized_end=433
# @@protoc_insertion_point(module_scope)
